==> public-sdk-2.0.21-sources.jar: com/voxeet/sdk/json/OfferCreated.java <==
package com.voxeet.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.voxeet.sdk.models.OfferCandidate;
import com.voxeet.sdk.models.OfferDescription;

import java.util.List;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.OFFER_CREATED)
public class OfferCreated extends Event {

    @JsonProperty("conference_id")
    private String conferenceId;

    @JsonProperty("user_id")
    private String userId;

    @JsonProperty("device_type")
    private String device;

    private String externalId;

    private String avatarUrl;

    private String name;

    private boolean master;

    private OfferDescription description;

    private List<OfferCandidate> candidates;

    public boolean isMaster() {
        return master;
    }

    public void setMaster(boolean master) {
        this.master = master;
    }

    public List<OfferCandidate> getCandidates() {
        return candidates;
    }

    public void setCandidates(List<OfferCandidate> candidates) {
        this.candidates = candidates;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public OfferDescription getDescription() {
        return description;
    }

    public void setDescription(OfferDescription description) {
        this.description = description;
    }

    public String getExternalId() {
        return externalId;
    }

    public void setExternalId(String externalId) {
        this.externalId = externalId;
    }

    public String getAvatarUrl() {
        return avatarUrl;
    }

    public void setAvatarUrl(String avatarUrl) {
        this.avatarUrl = avatarUrl;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String getType() {
        return EventNames.OFFER_CREATED;
    }
}

==> public-sdk-2.0.68-sources.jar: com/voxeet/sdk/json/OfferCreated.java <==
package com.voxeet.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.voxeet.sdk.models.v1.OfferCandidate;
import com.voxeet.sdk.models.v1.OfferDescription;
import com.voxeet.sdk.utils.Annotate;
import com.voxeet.sdk.utils.FromWebsocket;
import com.voxeet.sdk.utils.InternalEvent;

import java.util.List;

@Annotate
@InternalEvent
@FromWebsocket
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.OFFER_CREATED)
public class OfferCreated extends Event {

    @JsonProperty("conference_id")
    private String conferenceId;

    @JsonProperty("user_id")
    private String userId;

    @JsonProperty("device_type")
    private String device;

    private String externalId;

    private String avatarUrl;

    private String name;

    private boolean master;

    private OfferDescription description;

    private List<OfferCandidate> candidates;

    public boolean isMaster() {
        return master;
    }

    public void setMaster(boolean master) {
        this.master = master;
    }

    public List<OfferCandidate> getCandidates() {
        return candidates;
    }

    public void setCandidates(List<OfferCandidate> candidates) {
        this.candidates = candidates;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public OfferDescription getDescription() {
        return description;
    }

    public void setDescription(OfferDescription description) {
        this.description = description;
    }

    public String getExternalId() {
        return externalId;
    }

    public void setExternalId(String externalId) {
        this.externalId = externalId;
    }

    public String getAvatarUrl() {
        return avatarUrl;
    }

    public void setAvatarUrl(String avatarUrl) {
        this.avatarUrl = avatarUrl;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String getType() {
        return EventNames.OFFER_CREATED;
    }
}
